import ReactDOM from 'react-dom';

import {
  addGlobalUncaughtErrorHandler,
  registerMicroApps,
  runAfterFirstMounted,
  setDefaultMountApp,
  start,
} from 'qiankun';

import pkg from '../package.json';
import { FILTER_FOLER } from './utils/constants';

export const initMicroApps = loader => {
  debugger;
  registerMicroApps(
    [
      {
        name: 'web4_console',
        entry: `//${window.location.hostname}:3020/civweb4`,
        container: '#subapp-container',
        activeRule: location =>
          location.href.indexOf(`/${pkg.name.toLocaleLowerCase()}/civweb4`) !==
          -1,
        loader,
        props: {
          emitter: window.share.event,
          baseRoot: 'civweb4',
          globalConfig: JSON.stringify(
            createStoreage.get('globalConfig') || {},
          ),
          XMLHttpRequest: window.XMLHttpRequest,
        },
      },
    ],
    {
      beforeLoad: [
        app => {
          debugger;
          // hookRequest()
          console.log(
            '[LifeCycle] before load %c%s',
            'color: green;',
            JSON.stringify(app),
          );
        },
      ],
      beforeMount: [
        app => {
          debugger;
          // hookRequest()
          ReactDOM.unmountComponentAtNode(
            document.getElementById('subapp-container'),
          );
          console.log(
            '[LifeCycle] before mount %c%s',
            'color: green;',
            JSON.stringify(app),
          );
          // window.share.event.removeAllListeners();
        },
      ],
      beforeUnmount: [
        app => {
          debugger;
          console.log(
            '[LifeCycle] before unmount %c%s',
            'color: green;',
            JSON.stringify(app),
          );
        },
      ],
      afterUnmount: [
        app => {
          debugger;
          console.log(
            '[LifeCycle] after unmount %c%s',
            'color: green;',
            JSON.stringify(app),
          );
        },
      ],
    },
  );

  defaultApp();
  start({
    sandbox: {
      experimentalStyleIsolation: true,
      loose: true,
    },
    singular: false,
    scopedCSS: true,
    getPublicPath: window.__INJECTED_PUBLIC_PATH_BY_QIANKUN__,
    excludeAssetFilter: url => {
      return (
        url.indexOf('webapi.amap.com') !== -1 ||
        url.indexOf('api.map.baidu.com') !== -1 ||
        url.indexOf('map.baidu.com') !== -1 ||
        url.indexOf('pv.sohu.com') !== -1 ||
        url.indexOf('mt0.google.cn') !== -1 ||
        url.indexOf('mt1.google.cn') !== -1
      );
    },
  });
  runAfterFirstMounted(() => {
    console.log('[MainApp] first app mounted');
  });

  addGlobalUncaughtErrorHandler(event => console.log(event));
};

export const defaultApp = () => {
  const config = createStoreage.get('globalConfig');
  if (config && config.token) {
    const startWith = config.homepage ? config.homepage.split('/') : [];
    const basePath =
      FILTER_FOLER.indexOf(startWith[0]) > -1 ? 'civweb4' : 'civweb';
    setDefaultMountApp(
      `/${pkg.name.toLocaleLowerCase()}/${basePath}/?client=${config.client}`,
      //   config.homepage
      //     ? `/${pkg.name.toLocaleLowerCase()}/${basePath}/${config.homepage}`
      //     : `/${pkg.name.toLocaleLowerCase()}/${basePath}/?client=${
      //         window.globalConfig.client
      //       }`,
    );
  }
};
